@@ -33,22 +33,31 @@ class DNSServer(models.Model):
     location=models.CharField("Location",max_length=128,blank=True,null=True)
     provisioning=models.CharField("Provisioning",max_length=128,blank=True,null=True,
         help_text="Script for zone provisioning")
+    autozones_path=models.CharField("Autozones path",max_length=256,blank=True,null=True,
+        default="autozones",help_text="Prefix for autozones in config files")
     def __unicode__(self):
         if self.location:
             return "%s (%s)"%(self.name,self.location)
         else:
             return self.name
+    # Expands variables if any
+    def expand_vars(self,str):
+        return str%{
+            "rsync"    : config.get("path","rsync"),
+            "vcs_path" : config.get("cm","vcs_path"),
+            "repo"     : config.get("cm","repo"),
+            "ns"       : self.name,
+            "ip"       : self.ip,
+        }
+    
     def provision_zones(self):
         if self.provisioning:
             env=os.environ.copy()
             env["RSYNC_RSH"]=config.get("path","ssh")
-            cmd=self.provisioning%{
-                "rsync": config.get("path","rsync"),
-                "ns"   : self.name,
-                "ip"   : self.ip,
-            }
+            cmd=self.expand_vars(self.provisioning)
             retcode=subprocess.call(cmd,shell=True,cwd=os.path.join(config.get("cm","repo"),"dns"),env=env)
             return retcode==0
+            
     def _generator_class(self):
         return generator_registry[self.generator_name]
     generator_class=property(_generator_class)
